# steamspy

[![Documentation
Status](https://readthedocs.org/projects/steamspy/badge/?version=latest)](https://steamspy.readthedocs.org/en/latest/)

[steamspy](http://steamspy.com/) python api wrapper library.
